Metrix class

Constructors

Metrix()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isAndroid bool
no setter
isIOS bool
no setter
isWeb bool
no setter
getter/setter pair

Static Methods

deleteUserCustomId() → void
getAttributionData() Stream<MetrixAttribution>
getAutomationUserId() Stream<String>
getDeeplinkResponse() Future<String>
getMetrixUserId() Stream<String>
getSessionId() Stream<String>
getSessionNumber() Stream<int>
initialize(String appId, String apiKey, [Map<String, Object> config = const {}]) → void
loadInAppMessages() → void
newEvent(String slug, [Map<String, Object> attributes = const {}]) → void
newEventByName(String name, [Map<String, Object> attributes = const {}]) → void
newRevenue(String slug, double amount, {int currency = 0, String? orderId}) → void
newRevenueByName(String name, double amount, {int currency = 0, String? orderId}) → void
setPushToken(String token) → void
setSignature(String signature) → void
setUserAttributes(Map<String, Object> attributes) → void
setUserBirthday(double birthday) → void
setUserCity(String city) → void
setUserCountry(String country) → void
setUserCustomId(String id) → void
setUserEmail(String email) → void
setUserFirstName(String firstName) → void
setUserGender(String gender) → void
setUserHashedEmail(String hashedEmail) → void
setUserHashedPhoneNumber(String hashedPhoneNumber) → void
setUserLastName(String lastName) → void
setUserLocality(String locality) → void
setUserPhoneNumber(String phoneNumber) → void
setUserRegion(String region) → void
userChannelDisabled(String channel) → void
userChannelEnabled(String channel) → void