MetrixWeb class

Constructors

MetrixWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

deleteUserCustomId() → void
fetchAutomationUserId(dynamic callback(String?)) → void
fetchMetrixUserId(dynamic callback(String?)) → void
init(String appId, String apiKey, Map<String, Object> config) → void
newEvent(String slug, Map<String, Object> attributes) → void
newEventByName(String name, Map<String, Object> attributes) → void
newRevenue(String slug, double amount, int currency) → void
newRevenueByName(String name, double amount, int currency) → void
setUserAttributes(Map<String, Object> attributes) → void
setUserBirthday(double birthday) → void
setUserCity(String city) → void
setUserCountry(String country) → void
setUserCustomId(String id) → void
setUserEmail(String email) → void
setUserFirstName(String firstName) → void
setUserGender(String gender) → void
setUserHashedEmail(String hashedEmail) → void
setUserHashedPhoneNumber(String hashedPhoneNumber) → void
setUserLastName(String lastName) → void
setUserLocality(String locality) → void
setUserPhoneNumber(String phoneNumber) → void
setUserRegion(String region) → void